@@ -29,8 +29,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 __author__ = 'Alexandre Norman (norman at xael.org)'
-__version__ = '0.3.7'
-__last_modification__ = '2015.01.12'
+__version__ = '0.3.9'
+__last_modification__ = '2015.01.30'
 
 import datetime
 import logging
@@ -491,7 +491,7 @@ class Task(object):
     """
     Class for manipulating Tasks
     """
-    def __init__(self, name, start=None, stop=None, duration=None, depends_of=None, resources=None, percent_done=0, color=None, fullname=None):
+    def __init__(self, name, start=None, stop=None, duration=None, depends_of=None, resources=None, percent_done=0, color=None, fullname=None, display=True):
         """
         Initialize task object. Two of start, stop or duration may be given.
         This task can rely on other task and will be completed with resources.
@@ -508,6 +508,7 @@ class Task(object):
         resources -- list of Resources assigned to the task, default None
         percent_done -- int, percent of achievment, default 0
         color -- string, html color, default None
+        display -- boolean, display this task, default True
         """
         __LOG__.debug('** Task::__init__ {0}'.format({'name':name, 'start':start, 'stop':stop, 'duration':duration, 'depends_of':depends_of, 'resources':resources, 'percent_done':percent_done}))
         self.name = name
@@ -520,6 +521,7 @@ class Task(object):
         self.stop = stop
         self.duration = duration
         self.color = color
+        self.display = display
 
         ends = (self.start, self.stop, self.duration)
         nonecount = 0
@@ -791,6 +793,10 @@ class Task(object):
         """
         __LOG__.debug('** Task::svg ({0})'.format({'name':self.name, 'prev_y':prev_y, 'start':start, 'end':end, 'color':color, 'level':level}))
 
+        if not self.display:
+            __LOG__.debug('** Task::svg ({0}) display off'.format({'name':self.name}))
+            return(None, 0)
+
         add_modified_begin_mark = False
         add_modified_end_mark = False
 
@@ -814,6 +820,7 @@ class Task(object):
         add_end_mark = False
 
         y = prev_y * 10
+
                     
         # cas 1 -s--S==E--e-
         if self.start_date() >= start and self.end_date() <= end:
@@ -822,29 +829,29 @@ class Task(object):
             self.drawn_x_begin_coord = x
             self.drawn_x_end_coord = x+d
        # cas 5 -s--e--S==E-
-        elif self.start_date() >= end:
+        elif self.start_date() > end:
             return (None, 0)
         # cas 6 -S==E-s--e-
-        elif self.end_date() <= start:
+        elif self.end_date() < start:
             return (None, 0)
         # cas 2 -S==s==E--e-
         elif self.start_date() < start and self.end_date() <= end:
             x = 0
-            d = ((self.end_date() - start).days) * 10
+            d = ((self.end_date() - start).days + 1) * 10
             self.drawn_x_begin_coord = x
             self.drawn_x_end_coord = x+d
             add_begin_mark = True
         # cas 3 -s--S==e==E-
         elif self.start_date() >= start and  self.end_date() > end:
-            x = (self.start_date() - start).days * 10
-            d = ((end - self.start_date()).days) * 10
+            x = (self.start_date() - start).days * 10 
+            d = ((end - self.start_date()).days + 1) * 10
             self.drawn_x_begin_coord = x
             self.drawn_x_end_coord = x+d
             add_end_mark = True
         # cas 4 -S==s==e==E-
         elif self.start_date() < start and self.end_date() > end:
             x = 0
-            d = ((end - start).days) * 10
+            d = ((end - start).days + 1) * 10 
             self.drawn_x_begin_coord = x
             self.drawn_x_end_coord = x+d
             add_end_mark = True
@@ -1130,13 +1137,13 @@ class Project(object):
             if jour.weekday() == 0:
                 vlines.add(svgwrite.text.Text('{0:02}'.format(jour.isocalendar()[1]), insert=((x*10+1)*mm, 15*mm), fill='black', stroke='black', stroke_width=0, font_family="Verdana", font_size="16", font_weight="bold"))
 
-        vlines.add(svgwrite.shapes.Line(start=(maxx*cm, 1*cm), end=(maxx*cm, (maxy+1)*cm)))
+        vlines.add(svgwrite.shapes.Line(start=(maxx*cm, 2*cm), end=(maxx*cm, (maxy+2)*cm)))
 
 
         hlines = dwg.add(svgwrite.container.Group(id='hlines', stroke='lightgray'))
 
-        dwg.add(svgwrite.shapes.Line(start=((0)*cm, (2)*cm), end=((maxx+1)*cm, (2)*cm), stroke='black'))
-        dwg.add(svgwrite.shapes.Line(start=((0)*cm, (maxy+2)*cm), end=((maxx+1)*cm, (maxy+2)*cm), stroke='black'))
+        dwg.add(svgwrite.shapes.Line(start=((0)*cm, (2)*cm), end=((maxx)*cm, (2)*cm), stroke='black'))
+        dwg.add(svgwrite.shapes.Line(start=((0)*cm, (maxy+2)*cm), end=((maxx)*cm, (maxy+2)*cm), stroke='black'))
 
         for y in range(2, maxy+3):
             hlines.add(svgwrite.shapes.Line(start=(0*cm, y*cm), end=(maxx*cm, y*cm)))
@@ -1201,7 +1208,7 @@ class Project(object):
         dwg.save()
         return
 
-    def make_svg_for_resources(self, filename, today=None, start=None, end=None, resources=None, one_line_for_tasks=False):
+    def make_svg_for_resources(self, filename, today=None, start=None, end=None, resources=None, one_line_for_tasks=False, filter=''):
         """
         Draw resources affectation and output it to filename. If start or end are
         given, use them as reference, otherwise use project first and last day
@@ -1216,6 +1223,7 @@ class Project(object):
         end -- datetime.date of last day to draw
         resources -- list of Resource to check, default all
         one_line_for_tasks -- use only one line to display all tasks ?
+        filter -- display only those tags
         """
 
         if len(self.tasks) == 0:
@@ -1276,6 +1284,9 @@ class Project(object):
         conflict_display_line = 1
         for r in resources:
             # do stuff for each resource
+            if filter != '' and r.name not in filter:
+                continue
+
             ress = svgwrite.container.Group()
             ress.add(svgwrite.text.Text('{0}'.format(r.fullname), insert=(3*mm, (nline*10+7)*mm), fill='black', stroke='white', stroke_width=0, font_family="Verdana", font_size="18"))
             ldwg.add(ress)
@@ -1296,8 +1307,8 @@ class Project(object):
                      vac.add(svgwrite.shapes.Rect(
                             insert=(((cday - start_date).days * 10 + 1)*mm, ((conflict_display_line)*10+1)*mm),
                             size=(4*mm, 8*mm),
-                            fill="#00AA00",
-                            stroke="#00AA00",
+                            fill="#008000",
+                            stroke="#008000",
                             stroke_width=1,
                             opacity=0.65,
                             ))
@@ -1416,6 +1427,7 @@ class Project(object):
                 prj.add(trepr)
                 cy += theight
 
+
         fprj = svgwrite.container.Group()
         if self.name != "":
             # if ((self.start_date() >= start and self.end_date() <= end) 
@@ -1435,6 +1447,10 @@ class Project(object):
             else:
                 cy -= 1
 
+        # Do not display empty tasks
+        if (cy - prev_y) == 0 or (cy - prev_y) == 1:
+            return (None, 0)
+
         fprj.add(prj)
 
         return (fprj, cy-prev_y)
