@@ -23,8 +23,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 __author__ = 'Alexandre Norman (norman at xael.org)'
-__version__ = '0.3.7'
-__last_modification__ = '2015.01.12'
+__version__ = '0.3.9'
+__last_modification__ = '2015.01.30'
 
 
 import copy
@@ -77,6 +77,8 @@ def _iso_date_to_datetime(isodate):
 ############################################################################
 
 __LOG__ = None
+LISTE_IGNORE_TAGS = []
+LISTE_FILTER = []
 
 ############################################################################
 
@@ -125,6 +127,30 @@ def make_task_from_node(n, prop={}, prev_task=''):
     if ' ' in name:
         __LOG__.critical('** Space in task_id: [{0}]'.format(name))
         sys.exit(1)
+
+
+    # check if we should filter this task from display
+    global LISTE_FILTER
+    display = True
+    if len(LISTE_FILTER) > 0:
+        __LOG__.critical('FILTER:{0}'.format(n.tags))
+        for x in n.tags:
+            if x in LISTE_FILTER:
+                __LOG__.critical('FILTER FOUND:{0}'.format(x))
+                break
+        else:
+            __LOG__.critical('FILTER_PROP:{0}'.format(prop['resources']))
+            if prop['resources'] is not None:
+                for x in prop['resources'].replace('[','').replace(']','').split(','):
+                    if x in LISTE_FILTER:
+                        __LOG__.critical('FILTER FOUND:{0}'.format(x))
+                        break
+                else:
+                    display = False
+
+            else:
+                display = False
+        
     
     fullname = n.headline.strip().replace("'", '_')
     start = end = duration = None
@@ -163,15 +189,26 @@ def make_task_from_node(n, prop={}, prev_task=''):
             __LOG__.warning('** Task [{0}] marked as done but PercentDone is set to {1}'.format(name, percentdone))
         percentdone = 100
 
+
+    global LISTE_IGNORE_TAGS
+
+    resst = []
+
     # Resources as tag
     if len(n.tags) > 0:
-        ress = "{0}".format(["{0}".format(x) for x in n.tags.keys()]).replace("'", "")
+        resst = []
+        # Filter tags to ignore
+        for x in n.tags.keys():
+            if x not in LISTE_IGNORE_TAGS:
+                resst.append(x)
+
+        ress = "{0}".format(["{0}".format(x) for x in resst]).replace("'", "")
     # Resources as properties
     elif 'allocate' in n.properties:
         ress = "{0}".format(["{0}".format(x) for x in n.properties['allocate'].replace(",", " ").split()]).replace("'", "")
     else:
         try:
-            ress = prop['resources']
+            ress = "{0}".format(["{0}".format(x.strip()) for x in prop['resources'].replace('[','').replace(']','').split(',') if x not in LISTE_IGNORE_TAGS]).replace("'", "")
         except KeyError:
             ress = None
         except TypeError:
@@ -189,8 +226,11 @@ def make_task_from_node(n, prop={}, prev_task=''):
     else:
         color = None
 
+    if start is None and end is None and (duration is None or duration=='' or (duration != '' and depends_of is None)):
+        __LOG__.critical('** Task "{0}" : no start, stop, duration or dependencies -> not included in gantt !'.format(fullname))
+        return None
     
-    gantt_code += "task_{0} = gantt.Task(name='{1}', start={2}, stop={6}, duration={3}, resources={4}, depends_of={5}, percent_done={7}, fullname='{8}', color={9})\n".format(name, name, start, duration, ress, None, end, percentdone, fullname, color)
+    gantt_code += "task_{0} = gantt.Task(name='{1}', start={2}, stop={6}, duration={3}, resources={4}, depends_of={5}, percent_done={7}, fullname='{8}', color={9}, display={10})\n".format(name, name, start, duration, ress, None, end, percentdone, fullname, color, display)
 
     # store dependencies for later
     dependencies = str(depends_of).replace("'", "")
@@ -206,9 +246,11 @@ def make_task_from_node(n, prop={}, prev_task=''):
         'gantt': ('g',),
         'svg': ('S',),
         'resource': ('r',),
+        'availibility': ('a',),
         'start_date': ('s',),
         'end_date': ('e',),
         'today': ('t',),
+        'filter': ('f',),
         },
     extra = (
         clize.make_flag(
@@ -218,7 +260,7 @@ def make_task_from_node(n, prop={}, prev_task=''):
             ),
         )
     )
-def __main__(org, gantt='', start_date='', end_date='', today='', debug=False, resource='', svg='project'):
+def __main__(org, gantt='', start_date='', end_date='', today='', debug=False, resource=False, svg='project', filter='', availibility=''):
     """
     org2gantt.py
     
@@ -228,13 +270,17 @@ def __main__(org, gantt='', start_date='', end_date='', today='', debug=False, r
 
     svg: svg base name for files output
 
-    resource: check resource availibility between start_date and end_date
+    resource: generate resources graphe
+
+    availibility: check resource availibility between start_date and end_date
 
     start_date: force start date for output or used for checking resource availibility (format : 'yyyy-mm-dd')
 
     end_date: force end date for output or used for checking resource availibility (format : 'yyyy-mm-dd')
 
     today: force today date (format : 'yyyy-mm-dd')
+
+    filter: tag or list of tags separated by comas to filter
     
     debug: debug
 
@@ -289,6 +335,15 @@ import gantt
     my_today = datetime.date.today()
     bar_color = {'TODO':'#FFFF90'}
     one_line_for_tasks = False
+    global LISTE_IGNORE_TAGS
+    LISTE_IGNORE_TAGS = []
+
+    # List of tag to filter
+    global LISTE_FILTER
+    if filter != '':
+        LISTE_FILTER = filter.split(',')
+
+    __LOG__.debug('LISTE_FILTER : {0}'.format(LISTE_FILTER))
 
     # Generate code for configuration
     if n_configuration is not None:
@@ -296,6 +351,8 @@ import gantt
             if 'color_{0}'.format(t) in n_configuration.properties:
                 bar_color[t] = n_configuration.properties['color_{0}'.format(t)].strip()
 
+        if 'ignore_tags' in n_configuration.properties:
+             LISTE_IGNORE_TAGS = n_configuration.properties['ignore_tags'].split()
 
         if 'one_line_for_tasks' in n_configuration.properties and n_configuration.properties['one_line_for_tasks'].strip() == 't':
              one_line_for_tasks = True
@@ -360,6 +417,7 @@ import gantt
                     planning_end_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(years=qte*sign)))
 
 
+    __LOG__.debug('List of ignored tags : {0}'.format(LISTE_IGNORE_TAGS))
 
 
     # Find RESOURCES in heading
@@ -382,7 +440,7 @@ import gantt
     current_level = 0
     current_group = None
 
-    for nr in range(len(n_resources)):
+    for nr, r in enumerate(n_resources):
         r = n_resources[nr]
 
         rname = r.headline.strip().replace("'","_")
@@ -414,7 +472,7 @@ import gantt
             new_group_this_turn = True
         # Resource
         else:
-            gantt_code += "{0} = gantt.Resource('{1}')\n".format(rid, rname)
+            gantt_code += "{0} = gantt.Resource(name='{0}', fullname='{1}')\n".format(rid, rname)
             
         # Vacations in body of node
         for line in r.body.split('\n'):
@@ -466,7 +524,7 @@ import gantt
 
     # Generate code for Projects
     gantt_code += "\n#### Projects \n"
-    # Mother of all
+    # Mother of all 
     gantt_code += "project = gantt.Project(color='{0}')\n".format(bar_color['TODO'])
 
     prj_found = False
@@ -476,7 +534,7 @@ import gantt
     prev_task = None
     no_gantt_level = None
     late_dependencies = []
-    for nr in range(len(nodes)):
+    for nr, n in enumerate(nodes):
         n = nodes[nr]
 
         __LOG__.debug('Analysing {0}'.format(n.headline))
@@ -495,7 +553,10 @@ import gantt
             no_gantt_level = None
 
             # Add task
-            name, code, dependencies = make_task_from_node(n)
+            nt = make_task_from_node(n)
+            if nt is None:
+                continue
+            name, code, dependencies = nt
             late_dependencies.append([name, dependencies])
 
             if name in tasks_name:
@@ -591,9 +652,12 @@ import gantt
                     color['TODO'] = bar_color['TODO']
 
 
+
             # Inherits resources
             # Resources as tag
             if len(n.tags) > 0:
+                # For inherit all tags
+                #ress = "{0}".format(["{0}".format(x) for x in n.tags.keys() if x not in LISTE_IGNORE_TAGS]).replace("'", "")
                 ress = "{0}".format(["{0}".format(x) for x in n.tags.keys()]).replace("'", "")
                 # Resources as properties
             elif 'allocate' in n.properties:
@@ -646,10 +710,16 @@ import gantt
 
             # Add task
             if len(prop_inherits) > 0:
-                name, code, dependencies = make_task_from_node(n, prop_inherits[-1], prev_task)
+                nt = make_task_from_node(n, prop_inherits[-1], prev_task)
+                if nt is None:
+                    continue
+                name, code, dependencies = nt
                 late_dependencies.append([name, dependencies])
             else:
-                name, code, dependencies = make_task_from_node(n, [], prev_task)
+                nt = make_task_from_node(n, [], prev_task)
+                if nt is None:
+                    continue
+                name, code, dependencies = nt
                 late_dependencies.append([name, dependencies])
 
 
@@ -684,17 +754,19 @@ import gantt
         gantt_code += "task_{0}.add_depends(depends_of={1})\n".format(name, dep)
 
 
-    if resource == '':
+    if availibility == '':
         # Full project
         gantt_code += "\n#### Outputs \n"
 
 
         gantt_code += "project.make_svg_for_tasks(filename='{3}.svg', today={0}, start={1}, end={2})\n".format(planning_today_date, planning_start_date, planning_end_date, svg)
-        gantt_code += "project.make_svg_for_resources(filename='{4}_resources.svg', today={0}, start={1}, end={2}, one_line_for_tasks={3})\n".format(planning_today_date, planning_start_date, planning_end_date, one_line_for_tasks, svg)
+        # Generate resource graph
+        if resource:
+            gantt_code += "project.make_svg_for_resources(filename='{4}_resources.svg', today={0}, start={1}, end={2}, one_line_for_tasks={3}, filter='{5}')\n".format(planning_today_date, planning_start_date, planning_end_date, one_line_for_tasks, svg, filter)
 
     else:
         gantt_code += "\n#### Check resource availibility \n"
-        gantt_code += "print({0}.is_vacant(from_date={1}, to_date={2}))\n".format(resource, planning_start_date, planning_end_date)
+        gantt_code += "print({0}.is_vacant(from_date={1}, to_date={2}))\n".format(availibility, planning_start_date, planning_end_date)
         
 
 
